teatime.reporting package
=========================

Submodules
----------

teatime.reporting.issue module
------------------------------

.. automodule:: teatime.reporting.issue
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:


teatime.reporting.report module
-------------------------------

.. automodule:: teatime.reporting.report
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:


Module contents
---------------

.. automodule:: teatime.reporting
    :members:
    :undoc-members:
    :show-inheritance:
    :private-members:
